@@ -124,4 +124,31 @@ testthat::test_that("Sort pedigrees", {
   testthat::expect_error(purgeR::ip_F(arrui_unsort))
   arrui_sort <- purgeR::ped_sort(arrui_unsort)
   testthat::expect_equal(mean(purgeR::ip_F(arrui)$Fi), mean(purgeR::ip_F(arrui_sort)$Fi))
-})
\ No newline at end of file
+})
+
+testthat::test_that("Igraph format", {
+  data(atlas)
+  atlasg <- purgeR::ped_graph(atlas)
+  testthat::expect_type(atlasg, "list")
+  testthat::expect_equal(length(atlasg), 2)
+  testthat::expect_equal(names(atlasg), c("edges", "vertices"))
+  testthat::expect_success(testthat::expect_s3_class(atlasg$edges, "data.frame"))
+  testthat::expect_success(testthat::expect_s3_class(atlasg$vertices, "data.frame"))
+  testthat::expect_equal(names(atlasg$edges), c("from", "to", "from_parent", "to_parent"))
+  testthat::expect_equal(atlasg$vertices$id, atlas$id)
+  testthat::expect_equal(min(atlasg$edges$from), 1)
+  testthat::expect_equal(min(atlasg$edges$to), 4)
+  testthat::expect_equal(atlasg$edges[atlasg$edges[["from"]] == 15, "to"], 29)
+  testthat::expect_equal(atlasg$edges[atlasg$edges[["from"]] == 897, "to"], 948)
+  testthat::expect_equal(atlasg$edges[atlasg$edges[["from"]] == 26, "to"], c(55, 64))
+  testthat::expect_equal(sort(unique(atlasg$edges$from_parent)), c("dam", "sire"))
+  testthat::expect_equal(sort(unique(atlasg$edges$to_parent), na.last = TRUE), c("dam", "sire", NA))
+  testthat::expect_equal(length(atlasg$edges[atlasg$edges[["from"]] == 1, ]$from_parent), 20)
+  testthat::expect_equal(unique(atlasg$edges[atlasg$edges[["from"]] == 1, ]$from_parent), "sire")
+  testthat::expect_equal(unique(atlasg$edges[atlasg$edges[["from"]] == 2, ]$from_parent), "dam")
+  testthat::expect_equal(unique(atlasg$edges[atlasg$edges[["from"]] == 3, ]$from_parent), "dam")
+  testthat::expect_true(is.na(atlasg$edges[atlasg$edges[["from"]] == 15, "to_parent"]))
+  testthat::expect_true(is.na(atlasg$edges[atlasg$edges[["from"]] == 897, "to_parent"]))
+  testthat::expect_equal(length(atlasg$edges[atlasg$edges[["to"]] == 948, "to_parent"]), 2)
+  testthat::expect_true(all(is.na(atlasg$edges[atlasg$edges[["to"]] == 948, "to_parent"])))
+})
